summaryrefslogtreecommitdiffstats
path: root/raul/AtomicInt.h
diff options
context:
space:
mode:
Diffstat (limited to 'raul/AtomicInt.h')
-rw-r--r--raul/AtomicInt.h12
1 files changed, 9 insertions, 3 deletions
diff --git a/raul/AtomicInt.h b/raul/AtomicInt.h
index ba8e4b0..2678f31 100644
--- a/raul/AtomicInt.h
+++ b/raul/AtomicInt.h
@@ -1,11 +1,11 @@
-/* This file is part of Ingen. Copyright (C) 2007 Dave Robillard.
+/* This file is part of Raul. Copyright (C) 2007 Dave Robillard.
*
* Ingen is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* Ingen is distributed in the hope that it will be useful, but WITHOUT ANY
* WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
* FOR A PARTICULAR PURPOSE. See the GNU General Public License for details.
*
@@ -19,6 +19,9 @@
#include <glib.h>
+namespace Raul {
+
+
class AtomicInt {
public:
@@ -72,4 +75,7 @@ private:
volatile int _val;
};
+
+} // namespace Raul
+
#endif // RAUL_ATOMIC_INT_H
@@ -1,11 +1,11 @@
*
- * Ingen is free software; you can redistribute it and/or modify it under the
+ * Raul is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
@@ -1,11 +1,11 @@
* version.
*
- * Ingen is distributed in the hope that it will be useful, but WITHOUT ANY
+ * Raul is distributed in the hope that it will be useful, but WITHOUT ANY
* WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
* FOR A PARTICULAR PURPOSE. See the GNU General Public License for details.